Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(134)

Unified Diff: chrome/browser/android/banners/app_banner_settings_helper.h

Issue 884373002: Update content setting for app banners to store more information. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove unimplemented function Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/banners/app_banner_settings_helper.h
diff --git a/chrome/browser/android/banners/app_banner_settings_helper.h b/chrome/browser/android/banners/app_banner_settings_helper.h
index d1173a8866a0ead9da972b497e5645734a17311a..bf4e4123ab6a8688f1945e809410a9e3a3b26abc 100644
--- a/chrome/browser/android/banners/app_banner_settings_helper.h
+++ b/chrome/browser/android/banners/app_banner_settings_helper.h
@@ -8,6 +8,7 @@
#include <string>
#include "base/macros.h"
+#include "base/time/time.h"
namespace content {
class WebContents;
@@ -18,15 +19,24 @@ class GURL;
// Utility class for reading and updating ContentSettings for app banners.
class AppBannerSettingsHelper {
public:
- // Checks if a URL is allowed to show a banner for the given package.
+ // Records that a banner could have been shown for the given package or start
+ // url.
+ static void RecordCouldShowBannerEvent(
+ content::WebContents* web_contents,
+ const GURL& origin_url,
+ const std::string& package_name_or_start_url,
+ base::Time time);
+
+ // Checks if a URL is allowed to show a banner for the given package or start
+ // url.
static bool IsAllowed(content::WebContents* web_contents,
const GURL& origin_url,
- const std::string& package_name);
+ const std::string& package_name_or_start_url);
- // Blocks a URL from showing a banner for the given package.
+ // Blocks a URL from showing a banner for the given package or start url.
static void Block(content::WebContents* web_contents,
const GURL& origin_url,
- const std::string& package_name);
+ const std::string& package_name_or_start_url);
private:
DISALLOW_COPY_AND_ASSIGN(AppBannerSettingsHelper);

Powered by Google App Engine
This is Rietveld 408576698